@@ -3,5 +3,5 @@ import std_msgs
 import std_msgs.msg
 
 some_string = std_msgs.msg.String
-some_string.data = "Some Data in a std_msgs.msg.String"
+some_string.data = 'Some Data in a std_msgs.msg.String'
 print(some_string.data)
